@@ -476,8 +476,10 @@ void MainWindow::zoomFit() {
 
 void MainWindow::resizeEvent(QResizeEvent* event)
 {
-    adjustSizes();
     QWidget::resizeEvent(event);
+
+    // adjustSizes();
+    if ( m_pWebView || m_pGWebView )  setViewport();
 }
 
 void MainWindow::closeEvent(QCloseEvent *event)
@@ -791,8 +793,60 @@ void MainWindow::finishedRequest(QNetworkReply* reply)
     qDebug() << "Error(s): " << m_errors;
 }
 
+bool MainWindow::setViewport() {
+    QMultiMap<QString, QString> meta = m_webPage.mainFrame()->metaData();
+    QList<QString> viewport = meta.values("viewport");
+    if ( viewport.isEmpty() ) {
+        // keep same zoom?
+        setZoom(m_zoomFactor);
+        return false;
+    }
+
+    qreal zoom = m_zoomFactor;
+
+    qDebug() << "ViewPort: " << viewport;
+    QStringList list = viewport[0].split(QRegExp("[;,]\\s*"), QString::SkipEmptyParts);
+    foreach (QString str, list) {
+        int index = str.indexOf('=');
+        if ( index<0 ) continue;
+        QString param = str.mid(0, index).trimmed();
+        QString value = str.mid(index+1).trimmed();
+
+        if ( !param.compare("width") ) {
+            qDebug()<<"Viewport.Width = " << value;
+            if ( !value.compare("device-width") ) {
+                qDebug() << ">> zoom 1:1";
+                // 100%
+                setZoom(1);
+                return true;
+            }
+
+            bool ok =false;
+            int w = value.toInt(&ok);
+            if ( ok ) {
+                zoom = (qreal)width()/w;
+                qDebug() << ">> zoom: " << zoom;
+                setZoom(zoom);
+                return true;
+            }
+        }
+
+        if ( !param.compare("initial-scale") ) {
+            bool ok = false;
+            double z = value.toDouble(&ok);
+            if ( ok ) {
+                qDebug() << ">> Initial Scale: " << z;
+                zoom = z;
+            }
+        }
+    }
+
+    setZoom(zoom);
+    return false;
+}
+
 void MainWindow::hideLoading(bool success) {
-    setZoom(m_zoomFactor);
+    setViewport();
 
 #ifdef Q_WS_MAEMO_5
     setAttribute(Qt::WA_Maemo5ShowProgressIndicator, false);
